<?php

/*
 * Limbo2Joomla: Convert Limbo articles into Joomla.
 * 
 * Latest version is available at http://www.elias.cn/En/Limbo2Joomla
 *
 * @version V0.1 2011/05/21  (c) 2011 Elias Soong (elias.soong#gmail.com)  All rights reserved.
 *
 * Released under BSD license.
 */

/**
 * User Guide
 *
 * Tested under Limbo 1.0.4.2, Joomla 1.5.22, and PHP 5.2.5.
 *
 * 1, Limbo should use MySQL backend.
 * 2, Modify MySQL connection string for Limbo & Joomla in this source code.
 * 3, Upload all files of source code package (l2j.php and ADOdb libarary).
 * 4, Run l2j.php in your browser.
 * 5, Sections, categories, and articles should be already imported into your Joomla system.
 * 6, Copy all files of 'images' directory of Limbo into 'images' directory of Joomla.
 * 7, Create menus & modules in Joomla to display your articles.
 *
 * Wish this script could help you some. Regards!
 */


require_once("adodb5/adodb.inc.php");
require_once('adodb5/adodb-active-record.inc.php');


function replace_special($html){
    $html = mb_ereg_replace("(\[ES])|(\[DQ])|(\[CR])|(\[NL])", "", $html); 
    return mb_ereg_replace("src=\"images/", "src=\"/images/", $html);
}


// Read Limbo data:
ADODB_Active_Record::$_quoteNames = true;
echo 'Reading Limbo data:<br>';
$db_limbo = NewADOConnection('mysql://root:@localhost/yanxingintl?charset=utf8');
ADOdb_Active_Record::SetDatabaseAdapter($db_limbo, 'limbo');

class LmSection extends ADOdb_Active_Record
{
    var $_dbat = 'limbo';
    var $_table = 'lm_sections';
}

class LmCategory extends ADOdb_Active_Record
{
    var $_dbat = 'limbo';
    var $_table = 'lm_categories';
}

class LmContent extends ADOdb_Active_Record
{
    var $_dbat = 'limbo';
    var $_table = 'lm_content';
}

$lm_section = new LmSection();
$lm_sections = $lm_section->Find('');

$lm_category = new LmCategory();
$lm_categories = $lm_category->Find('');
    
$lm_content = new LmContent();
$lm_contents = $lm_content->Find('');
//var_dump($lm_content->getAttributeNames());
//print_r($contents);


// Write data into Joomla:
echo 'Reading finished! Start writing data into Joomla:<br>'; 
$db_joomla = NewADOConnection('mysql://root:@localhost/jom?charset=utf8');
ADOdb_Active_Record::SetDatabaseAdapter($db_joomla, 'joomla');

class JosUser extends ADOdb_Active_Record
{
    var $_dbat = 'joomla';
    var $_table = 'jos_users';
}

class JosSection extends ADOdb_Active_Record
{
    var $_dbat = 'joomla';
    var $_table = 'jos_sections';
}

class JosCategory extends ADOdb_Active_Record
{
    var $_dbat = 'joomla';
    var $_table = 'jos_categories';
}

class JosContent extends ADOdb_Active_Record
{
    var $_dbat = 'joomla';
    var $_table = 'jos_content';
}

$section_dic = array();
echo '--------<br>';
foreach($lm_sections as $section){
    echo 'Writing section id '.$section->id.'...<br>';
    $jos_section = new JosSection();
    $jos_section->title = $section->title;
    $jos_section->name = $section->name;
    $jos_section->alias = $section->id;
    $jos_section->image = $section->image;
    $jos_section->scope = 'content';
    $jos_section->image_position = $section->image_position;
    $jos_section->description = replace_special($section->description);
    $jos_section->published = $section->published;
    $jos_section->checked_out = 0;
    $jos_section->checked_out_time = '0000-00-00 00:00:00';
    $jos_section->ordering = $section->ordering;
    $jos_section->access = $section->access;
    $jos_section->count = $section->count;
    $jos_section->params = '';
    $jos_section->save();
    $section_dic[$section->id] = $jos_section->id;
}

$category_dic = array();
echo '--------<br>';
foreach($lm_categories as $category){
    if (isset($section_dic[$category->section])) {
        echo 'Writing category id '.$category->id.'...<br>';
        $jos_category = new JosCategory();
        $jos_category->parent_id = $category->parent_id;
        $jos_category->title = $category->title;
        $jos_category->name = $category->name;
        $jos_category->alias = $category->id;
        $jos_category->image = $category->image;
        $jos_category->section = $section_dic[$category->section];
        $jos_category->image_position = $category->image_position;
        $jos_category->description = replace_special($category->description);
        $jos_category->published = $category->published;
        $jos_category->checked_out = 0;
        $jos_category->checked_out_time = '0000-00-00 00:00:00';
        $jos_category->ordering = $category->ordering;
        $jos_category->access = $category->access;
        $jos_category->count = $category->count;
        $jos_category->params = '';
        $jos_category->save();
        $category_dic[$category->id] = $jos_category->id;
    }
}

$user = new JosUser();
$user->load("usertype='Super Administrator'");
$admin_id = $user->id;
echo $user->ErrorMsg();
echo '--------<br>';
foreach ($lm_contents as $content){
    echo 'Writing content id '.$content->id.'...<br>';
    $jos_content = new JosContent();
    $jos_content->title = $content->title;
    $jos_content->alias = $content->id;
    $jos_content->title_alias = $content->title_alias;
    $jos_content->introtext = replace_special($content->introtext);
    $jos_content->fulltext = replace_special($content->bodytext);
    $jos_content->state = $content->published;
    $jos_content->sectionid = $section_dic[$content->sectionid];
    $jos_content->mask = $content->mask;
    $jos_content->catid = $category_dic[$content->catid];
    $jos_content->created = date('Y-m-d H:i:s', $content->created);
    $jos_content->created_by = $admin_id;
    $jos_content->created_by_alias = '';
    $jos_content->modified = $content->modified;
    $jos_content->modified_by = $admin_id;
    $jos_content->checked_out = 0;
    $jos_content->checked_out_time = '0000-00-00 00:00:00';
    $jos_content->publish_up = date('Y-m-d H:i:s', $content->created);
    $jos_content->publish_down = '0000-00-00 00:00:00';
    $jos_content->images = '';
    $jos_content->urls = '';
    $jos_content->attribs = '';
    $jos_content->version = 1;
    $jos_content->parentid = 0;
    $jos_content->ordering = $content->ordering;
    $jos_content->metakey = $content->metakey;
    $jos_content->metadesc = $content->metadesc;
    $jos_content->access = $content->access;
    $jos_content->hits = $content->hits;
    $jos_content->metadata = '';
    $jos_content->save();
}

echo $lm_content->ErrorMsg();
echo '<br>';
echo '==== Finshed! ====';
//print_r($section_dic);
echo '<br>';
//print_r($category_dic);

?>

